@@ -78,7 +78,7 @@ void Titraqform::setupPrefs(void)
     QString Username;
 
 // Start the show by getting the username
-#if defined(Q_WS_WIN)
+#if defined(Q_OS_WIN32)
     {
         DWORD dwWinusernamesize = sizeof(dwWinusernamesize);
 #if defined(UNICODE)
@@ -99,7 +99,7 @@ void Titraqform::setupPrefs(void)
 //        Username = QString::fromLocal8Bit(szUser);
         Username = QString::fromLocal8Bit(getlogin());
     }
-#endif  // #if defined(Q_WS_WIN)
+#endif  // #if defined(Q_OS_WIN32)
 
     m_pPrefs = new Preferences(TITRAQ_PREFNAME, TITRAQ_APPTITLE, TITRAQ_PREFVER);
     if (!m_pPrefs->fileState()) {   // No file was found, so assume a null state
@@ -175,7 +175,7 @@ void Titraqform::setupActions(void)
     m_pFileopenact = new QAction(trUtf8("Open File"), QPixmap(s_kpcFileopen_xpm), trUtf8("&Open..."), CTRL+Key_O, this, "Open");
     if (m_pFileopenact == NULL) // Sanity check
         throw Genexcept("Main window file open action creation failed.");
-    connect(m_pFileopenact, SIGNAL(activated()), this, SLOT(chooseFile()));
+    connect(m_pFileopenact, SIGNAL(activated()), this, SLOT(openDoc()));
     const char *kszFileopentext = "<p><img source=\"fileopen\"> "
                                   "Click this button to open a "
                                   "<em>new file</em>. You can also select "
@@ -498,7 +498,7 @@ void Titraqform::setupTable(void)
     connect(m_pMaintable, SIGNAL(currentChanged(int, int)), this, SLOT(updEdit(int, int)));
     connect(m_pMaintable, SIGNAL(doubleClicked(int, int, int, const QPoint&)), this, SLOT(inplaceEdit(int, int, int, const QPoint&)));
     connect(m_pTablehead, SIGNAL(sizeChange(int, int, int)), this, SLOT(updSizes(int, int, int)));
-//    connect(m_pMaintable, SIGNAL(valueChanged(int, int)), this, SLOT(tableChanged(int, int)));
+    connect(m_pMaintable, SIGNAL(valueChanged(int, int)), this, SLOT(dataChanged(int, int)));
 }
 
 //
