@@ -48,6 +48,7 @@
 #define TITRAQ_DEFREMOTELOG     "no"
 #define TITRAQ_PREFLOCALLOG     "loglocal"
 #define TITRAQ_DEFLOCALLOG      "no"
+#define TITRAQ_SAVEFIRST        "The timesheet contains unsaved changes\nDo you want to save the changes or discard them?"
 
 // Other string constants
 #define TITRAQ_DATEZERO         "0000-00-00"
@@ -77,5 +78,8 @@
 #define TITRAQ_MINAMOUNT        0           // Minimum valid amount
 #define TITRAQ_STEPAMOUNT       15          // Line step interval
 #define TITRAQ_MINSINHOUR       60          // Only idiots don't know this
+#define TITRAQ_YES              1           // To signal yes in general
+#define TITRAQ_NO               0           // To signal no in general
+#define TITRAQ_CANCEL           -1          // To not signal anything
 
 #endif // TITCONST_H
