@@ -85,8 +85,10 @@ void Titraqform::pasteEntry(void)
     nRows = Selection.contains(QChar('\n'));        // How many rows
     this->addEntry(nRows);                          // Reuse slot
 
-    if (Selection)
+    if (Selection) {
         setRowdata(Selection);                      // Use accessor
+        this->setDirty(true);                       // Set dirty state
+    }
 }
 
 //
@@ -104,10 +106,12 @@ void Titraqform::addEntry(int nRows)
         // Add a row after selection and focus to the new row
         if (Select.bottomRow() + 1 != m_pMaintable->numRows()) { // Add upwards
             m_pMaintable->insertRows(Select.topRow(), nTotal);
+            this->setDirty(true);   // Set data to dirty state
             m_pMaintable->setCurrentCell(Select.topRow(), m_pMaintable->currentColumn());
         }
         else { // Special case on last row add downwards
             m_pMaintable->insertRows(Select.bottomRow() + 1, nTotal);
+            this->setDirty(true);   // Set data to dirty state
             m_pMaintable->setCurrentCell(Select.bottomRow() + 1, m_pMaintable->currentColumn());
             m_pMaintable->ensureCellVisible(m_pMaintable->numRows() - 1, 0); // Scroll please
         }
@@ -118,10 +122,12 @@ void Titraqform::addEntry(int nRows)
         // Add a row after selection and focus to the new row
         if (nCurrent + 1 != m_pMaintable->numRows()) { // Add upwards
             m_pMaintable->insertRows(nCurrent, nTotal);
+            this->setDirty(false);  // Reset data to clean state
             m_pMaintable->setCurrentCell(nCurrent, m_pMaintable->currentColumn());
         }
         else { // Special case on last row add downwards
             m_pMaintable->insertRows(nCurrent + 1, nTotal);
+            this->setDirty(false);  // Reset data to clean state
             m_pMaintable->setCurrentCell(nCurrent + 1, m_pMaintable->currentColumn());
             m_pMaintable->ensureCellVisible(m_pMaintable->numRows() - 1, 0); // Scroll please
         }
@@ -157,9 +163,12 @@ void Titraqform::delEntry(int nRows)
     if (m_pMaintable->currentRow() + 1 != m_pMaintable->numRows()) {
         m_pMaintable->setCurrentCell(Select.bottomRow() + 1, m_pMaintable->currentColumn());
         m_pMaintable->removeRows(Rowselect);
+        this->setDirty(true);   // Set data to dirty state
     }
-    else // Special case to handle removing of only row or last row
+    else {  // Special case to handle removing of only row or last row
         m_pMaintable->removeRows(Rowselect);
+        this->setDirty(true);   // Set data to dirty state
+    }
 }
 
 //
@@ -167,29 +176,100 @@ void Titraqform::delEntry(int nRows)
 //
 void Titraqform::newDoc(void)
 {
-    m_pMaintable->setNumRows(0); // Get rid of any data in table
+    int nResult = 0;
+
+    // Check modification state of current data
+    if (this->isDirty()) {
+        nResult = QMessageBox::information(this, trUtf8(TITRAQ_APPTITLE),
+                  trUtf8(TITRAQ_SAVEFIRST), trUtf8("&Save"),
+                  trUtf8("&Discard"), trUtf8("Cancel"), 0, 2);
+
+        switch (nResult) {
+        case 0: // Save first
+            this->saveFile();               // Save changes first
+            m_pMaintable->setNumRows(0);    // Remove all data in table
+            this->setDirty(false);          // Reset data to clean state
+            break;
+        case 1: // Don't save first but do new
+            m_pMaintable->setNumRows(0);    // Remove all data in table
+            this->setDirty(false);          // Reset data to clean state
+            break;
+        case 2: // Don't do a new timesheet
+        default:
+            break;
+        }
+    }
+    else {                                  // Data is already up to date
+        m_pMaintable->setNumRows(0);        // Remove all data in table
+        this->setDirty(false);              // Reset data to clean state
+    }
 }
 
 //
-// Choose a file using a handy file dialog
+// Open and display an existing document
 //
-void Titraqform::chooseFile(void)
+void Titraqform::openDoc(void)
 {
+    int nResult = 0;    // Holds return value from save first messagebox
     QString Filestring = QFileDialog::getOpenFileName("/e/dev/as", QString::null, this, trUtf8("Chooser Dialog"), trUtf8("Choose a file to open"));
+
     if (!Filestring.isEmpty()) {
-        m_szFilename->operator=(Filestring);
-        m_pMaintable->setNumRows(0);    // Clear out old data
-        QFile Filetemp(Filestring);     // File to load
-        try {
-            loadData(Filetemp);         // Pass to helper method
+        QFile Filetemp(Filestring); // File to load
+        // Check modification state of current data
+        if (this->isDirty()) {
+            nResult = QMessageBox::information(this, trUtf8(TITRAQ_APPTITLE),
+                      trUtf8(TITRAQ_SAVEFIRST), trUtf8("&Save"),
+                      trUtf8("&Discard"), trUtf8("Cancel"), 0, 2);
+
+            switch (nResult) {
+            case 0: // Save first
+                this->saveFile();               // Save changes first
+                m_szFilename->operator=(Filestring);
+                m_pMaintable->setNumRows(0);    // Clear out old data
+                try {
+                    loadData(Filetemp);         // Pass to helper method
+                }
+                catch (Genexcept& Genex) {
+                    Genex.reportErr();
+                }
+                // Reset and give output to main window
+                this->setCaption(Filestring);
+                m_pStatbar->message(trUtf8("Loaded document ") + Filestring, 4000);
+                this->setDirty(false);          // Set the clean state
+                break;
+            case 1: // Don't save first but do load
+                m_szFilename->operator=(Filestring);
+                m_pMaintable->setNumRows(0);    // Clear out old data
+                try {
+                    loadData(Filetemp);         // Pass to helper method
+                }
+                catch (Genexcept& Genex) {
+                    Genex.reportErr();
+                }
+                // Reset and give output to main window
+                this->setCaption(Filestring);
+                m_pStatbar->message(trUtf8("Loaded document ") + Filestring, 4000);
+                this->setDirty(false);          // Set the clean state
+                break;
+            case 2: // Don't do a load timesheet
+            default:
+                break;
+            }
         }
-        catch (Genexcept& Genex) {
-            Genex.reportErr();
+        else {
+            m_szFilename->operator=(Filestring);
+            m_pMaintable->setNumRows(0);    // Clear out old data
+            try {
+                loadData(Filetemp);         // Pass to helper method
+            }
+            catch (Genexcept& Genex) {
+                Genex.reportErr();
+            }
+            // Reset and give output to main window
+            this->setCaption(Filestring);
+            m_pStatbar->message(trUtf8("Loaded document ") + Filestring, 4000);
+            this->setDirty(false);          // Set the clean state
         }
-        // Reset and give output to main window
-        this->setCaption(Filestring);
-        m_pStatbar->message(trUtf8("Loaded document ") + Filestring, 4000);
-        this->setDirty(false);          // Set the clean state
     }
     else
         m_pStatbar->message(trUtf8("Loading aborted"), 4000);
@@ -242,27 +322,33 @@ void Titraqform::saveAs(void)
 //
 void Titraqform::closeEvent(QCloseEvent *pClosit)
 {
-    // Check modification state of current data
-    if (!this->isDirty()) {
-        pClosit->accept();
-        return;
-    }
+    int nResult = 0;
 
-    // Ask user to acknowlege a possibly data-damaging close event
-    switch(QMessageBox::information(this, "OSSP titraq",
-        trUtf8("The document has been\nchanged since the last save.")),
-        trUtf8("Save Now"), trUtf8("Cancel"), trUtf8("Leave Anyway"), 0, 1) {
-    case 0:
-        saveFile();
+    // Check modification state of current data
+    if (this->isDirty()) {
+        nResult = QMessageBox::information(this, trUtf8(TITRAQ_APPTITLE),
+                  trUtf8(TITRAQ_SAVEFIRST), trUtf8("&Save"),
+                  trUtf8("&Discard"), trUtf8("Cancel"), 0, 2);
+
+        switch (nResult) {
+        case 0: // Save first
+            this->saveFile();               // Save changes first
+            pClosit->accept();              // then close timesheet
+            this->setDirty(false);          // Reset data to clean state
+            break;
+        case 1: // Don't save first but close
+            pClosit->accept();              // Close timesheet
+            this->setDirty(false);          // Reset data to clean state
+            break;
+        case 2: // Don't close
+        default:
+            pClosit->ignore();
+            break;
+        }
+    }
+    else {                                  // Data is already up to date
         pClosit->accept();
-        break;
-    case 1:
-        default:    // Just for sanity
-        pClosit->ignore();
-        break;
-    case 2:
-        pClosit->accept();
-        break;
+        this->setDirty(false);              // Reset data to clean state
     }
 }
 
@@ -324,6 +410,14 @@ void Titraqform::updSizes(int nSection, int nOldsize, int nNewsize)
     }
 }
 
+//
+//
+//
+void Titraqform::dataChanged(int nRow, int nCol)
+{
+    setDirty(); // Mark this timesheet dirty, changes pending save
+}
+
 //
 // Update the edit controls contents
 //
